==> login_firebase-0.0.2.tar.gz: lib/presentation/widgets/single/GoogleSigninWidget.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/business/bloc/GoogleSigninBloc.dart';
import 'package:login_firebase/business/dto/ModSessionDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/factories/LoginIconButtonFactory.dart';
import 'package:login_firebase/presentation/factories/LoginWidgetFactory.dart';
import 'package:login_firebase/presentation/resources/LoginColors.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';

import '../base/ModBaseStatelessWidgetWithBloc.dart';


const String TAG = "GoogleSigninWidget";


/**
 * Widget that performs Google sign-in
 */

//ignore: must_be_immutable
class GoogleSigninWidget extends ModBaseStatelessWidgetWithBloc<GoogleSigninBloc, ThirdPartySessionModel> {
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;
  final Function(String)? onDisplay;
  final bool available;
  final String btnText;
  final Color? loadingColor;
  
  GoogleSigninWidget({
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    this.onDisplay,
    this.available = true,
    required this.btnText,
    this.loadingColor,
    Key? key})
      : super(key: key);

  @override
  void initBloc(BuildContext context) {
    this.bloc = GoogleSigninBloc();
  }

  void _call() {
    this.bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    this.bloc!.performOperation(ModSessionDTO(mail: "", pass: ""));
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return this._wrap(this._buildButton(context));
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    final btn = this._buildButton(context);

    return this._wrap(Stack(children: <Widget>[
      btn,
      ModLoadingWidget(color: this.loadingColor,)
    ],));
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    final btn = this._buildButton(context);

    if (data!.validate()) {
      this.onSessionSuccess.call(data);
    } else {
      this.onSessionError.call(ModErrorCodes.INVALID_SESSION);
    }
    return this._wrap(btn);
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    final btn = this._buildButton(context);
    this.onSessionError.call(error!.code);
    return this._wrap(btn);
  }

  Widget _wrap(Widget child) => Container(
      margin: EdgeInsets.symmetric(horizontal: 8.0),
      padding: EdgeInsets.all(4.0),
      child: Center(child: child)
  );

  Widget _buildButton(BuildContext context) => LoginWidgetFactory.buildSigninBtn(
      context: context,
      containerColor: LoginColors.whiteColor,
      borderColor: LoginColors.blackColor,
      icon: LoginIconButtonFactory.getGoogleIcon(height: 25.0, width: 25.0),
      text: this.btnText,
      textColor: LoginColors.blackColor,
      onClick: this.available?
          // AVAIL
          () {
            this.onReset.call();

            this._call();
          }
            :
          // NOT AVAIL
          () {
            this.onSessionError(ModErrorCodes.SIGNIN_NOT_AVAILABLE);
          }
  );
}

==> login_firebase-0.0.4.tar.gz: lib/presentation/widgets/single/GoogleSigninWidget.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/business/bloc/GoogleSigninBloc.dart';
import 'package:login_firebase/business/dto/ModSessionDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/factories/LoginIconButtonFactory.dart';
import 'package:login_firebase/presentation/factories/LoginWidgetFactory.dart';
import 'package:login_firebase/presentation/resources/LoginColors.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';

import '../base/ModBaseStatelessWidgetWithBloc.dart';


const String TAG = "GoogleSigninWidget";


//ignore: must_be_immutable
class GoogleSigninWidget extends ModBaseStatelessWidgetWithBloc<GoogleSigninBloc, ThirdPartySessionModel> {
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;
  final Function(String)? onDisplay;
  final bool available;
  final String btnText;
  final Color? loadingColor;
  
  GoogleSigninWidget({
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    this.onDisplay,
    this.available = true,
    required this.btnText,
    this.loadingColor,
    super.key});

  @override
  void initBloc(BuildContext context) {
    bloc = GoogleSigninBloc();
  }

  void _call() {
    bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    bloc!.performOperation(const ModSessionDTO(mail: "", pass: ""));
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return _wrap(_buildButton(context));
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    final btn = _buildButton(context);

    return _wrap(Stack(children: <Widget>[
      btn,
      ModLoadingWidget(color: loadingColor,)
    ],));
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    final btn = _buildButton(context);

    if (data!.validate()) {
      onSessionSuccess.call(data);
    } else {
      onSessionError.call(ModErrorCodes.INVALID_SESSION);
    }
    return _wrap(btn);
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    final btn = _buildButton(context);
    onSessionError.call(error!.code);
    return _wrap(btn);
  }

  Widget _wrap(Widget child) => Container(
      margin: const EdgeInsets.symmetric(horizontal: 8.0),
      padding: const EdgeInsets.all(4.0),
      child: Center(child: child)
  );

  Widget _buildButton(BuildContext context) => LoginWidgetFactory.buildSigninBtn(
      context: context,
      containerColor: LoginColors.whiteColor,
      borderColor: LoginColors.blackColor,
      icon: LoginIconButtonFactory.getGoogleIcon(height: 25.0, width: 25.0),
      text: btnText,
      textColor: LoginColors.blackColor,
      onClick: available?
          // AVAIL
          () {
            onReset.call();

            _call();
          }
            :
          // NOT AVAIL
          () {
            onSessionError(ModErrorCodes.SIGNIN_NOT_AVAILABLE);
          }
  );
}
